@@ -24,7 +24,6 @@ static struct cdevsw nvidia_ctl_cdevsw = {
     .d_poll =      nvidia_ctl_poll,
     .d_name =      "nvidiactl",
     .d_version =   D_VERSION,
-    .d_flags =     D_TRACKCLOSE
 };
 
 static struct cdev *nvidia_ctl_cdev = NULL;
@@ -75,8 +74,6 @@ static void nvidia_ctl_dtor(void *arg)
     status = nvidia_close_ctl(nv, filep);
     nv_unlock_api(nv);
 
-    devfs_clear_cdevpriv();
-
     while ((et = STAILQ_FIRST(&filep->event_queue))) {
         STAILQ_REMOVE(&filep->event_queue, et, nvidia_event, queue);
         free(et, M_NVIDIA);
