@@ -1848,6 +1848,15 @@ RM_STATUS NV_API_CALL nv_acpi_dsm_method(
     return RM_ERR_NOT_SUPPORTED;
 }
 
+RM_STATUS NV_API_CALL nv_acpi_ddc_method(
+    nv_state_t *nv,
+    void *pEdidBuffer,
+    NvU32 *pSize
+)
+{
+    return RM_ERR_NOT_SUPPORTED;
+}
+
 void* NV_API_CALL nv_get_smu_state(void)
 {
     return NULL;
